==> esp8266-0.3.0.crate: esp8266-0.3.0/src/slc/slc_rx_dscr_conf.rs <==
#[doc = "Register `SLC_RX_DSCR_CONF` reader"]
pub struct R(crate::R<SLC_RX_DSCR_CONF_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_RX_DSCR_CONF_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<SLC_RX_DSCR_CONF_SPEC>> for R {
    fn from(reader: crate::R<SLC_RX_DSCR_CONF_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_RX_DSCR_CONF` writer"]
pub struct W(crate::W<SLC_RX_DSCR_CONF_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_RX_DSCR_CONF_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<SLC_RX_DSCR_CONF_SPEC>> for W {
    fn from(writer: crate::W<SLC_RX_DSCR_CONF_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_INFOR_NO_REPLACE` reader - "]
pub struct SLC_INFOR_NO_REPLACE_R(crate::FieldReader<bool, bool>);
impl SLC_INFOR_NO_REPLACE_R {
    pub(crate) fn new(bits: bool) -> Self {
        SLC_INFOR_NO_REPLACE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_INFOR_NO_REPLACE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_INFOR_NO_REPLACE` writer - "]
pub struct SLC_INFOR_NO_REPLACE_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_INFOR_NO_REPLACE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN_NO_REPLACE` reader - "]
pub struct SLC_TOKEN_NO_REPLACE_R(crate::FieldReader<bool, bool>);
impl SLC_TOKEN_NO_REPLACE_R {
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TOKEN_NO_REPLACE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN_NO_REPLACE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN_NO_REPLACE` writer - "]
pub struct SLC_TOKEN_NO_REPLACE_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN_NO_REPLACE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
        self.w
    }
}
impl R {
    #[doc = "Bit 9"]
    #[inline(always)]
    pub fn slc_infor_no_replace(&self) -> SLC_INFOR_NO_REPLACE_R {
        SLC_INFOR_NO_REPLACE_R::new(((self.bits >> 9) & 0x01) != 0)
    }
    #[doc = "Bit 8"]
    #[inline(always)]
    pub fn slc_token_no_replace(&self) -> SLC_TOKEN_NO_REPLACE_R {
        SLC_TOKEN_NO_REPLACE_R::new(((self.bits >> 8) & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 9"]
    #[inline(always)]
    pub fn slc_infor_no_replace(&mut self) -> SLC_INFOR_NO_REPLACE_W {
        SLC_INFOR_NO_REPLACE_W { w: self }
    }
    #[doc = "Bit 8"]
    #[inline(always)]
    pub fn slc_token_no_replace(&mut self) -> SLC_TOKEN_NO_REPLACE_W {
        SLC_TOKEN_NO_REPLACE_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_RX_DSCR_CONF\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_rx_dscr_conf](index.html) module"]
pub struct SLC_RX_DSCR_CONF_SPEC;
impl crate::RegisterSpec for SLC_RX_DSCR_CONF_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_rx_dscr_conf::R](R) reader structure"]
impl crate::Readable for SLC_RX_DSCR_CONF_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_rx_dscr_conf::W](W) writer structure"]
impl crate::Writable for SLC_RX_DSCR_CONF_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_RX_DSCR_CONF to value 0"]
impl crate::Resettable for SLC_RX_DSCR_CONF_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/slc/slc_rx_dscr_conf.rs <==
#[doc = "Register `SLC_RX_DSCR_CONF` reader"]
pub struct R(crate::R<SLC_RX_DSCR_CONF_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_RX_DSCR_CONF_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SLC_RX_DSCR_CONF_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SLC_RX_DSCR_CONF_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_RX_DSCR_CONF` writer"]
pub struct W(crate::W<SLC_RX_DSCR_CONF_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_RX_DSCR_CONF_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SLC_RX_DSCR_CONF_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SLC_RX_DSCR_CONF_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_INFOR_NO_REPLACE` reader - "]
pub struct SLC_INFOR_NO_REPLACE_R(crate::FieldReader<bool, bool>);
impl SLC_INFOR_NO_REPLACE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_INFOR_NO_REPLACE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_INFOR_NO_REPLACE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_INFOR_NO_REPLACE` writer - "]
pub struct SLC_INFOR_NO_REPLACE_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_INFOR_NO_REPLACE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN_NO_REPLACE` reader - "]
pub struct SLC_TOKEN_NO_REPLACE_R(crate::FieldReader<bool, bool>);
impl SLC_TOKEN_NO_REPLACE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TOKEN_NO_REPLACE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN_NO_REPLACE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN_NO_REPLACE` writer - "]
pub struct SLC_TOKEN_NO_REPLACE_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN_NO_REPLACE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
        self.w
    }
}
impl R {
    #[doc = "Bit 9"]
    #[inline(always)]
    pub fn slc_infor_no_replace(&self) -> SLC_INFOR_NO_REPLACE_R {
        SLC_INFOR_NO_REPLACE_R::new(((self.bits >> 9) & 0x01) != 0)
    }
    #[doc = "Bit 8"]
    #[inline(always)]
    pub fn slc_token_no_replace(&self) -> SLC_TOKEN_NO_REPLACE_R {
        SLC_TOKEN_NO_REPLACE_R::new(((self.bits >> 8) & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 9"]
    #[inline(always)]
    pub fn slc_infor_no_replace(&mut self) -> SLC_INFOR_NO_REPLACE_W {
        SLC_INFOR_NO_REPLACE_W { w: self }
    }
    #[doc = "Bit 8"]
    #[inline(always)]
    pub fn slc_token_no_replace(&mut self) -> SLC_TOKEN_NO_REPLACE_W {
        SLC_TOKEN_NO_REPLACE_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_RX_DSCR_CONF\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_rx_dscr_conf](index.html) module"]
pub struct SLC_RX_DSCR_CONF_SPEC;
impl crate::RegisterSpec for SLC_RX_DSCR_CONF_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_rx_dscr_conf::R](R) reader structure"]
impl crate::Readable for SLC_RX_DSCR_CONF_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_rx_dscr_conf::W](W) writer structure"]
impl crate::Writable for SLC_RX_DSCR_CONF_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_RX_DSCR_CONF to value 0"]
impl crate::Resettable for SLC_RX_DSCR_CONF_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
